"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatatableWrapper = exports.useDatatableWrapper = void 0;
const react_1 = __importStar(require("react"));
const data_1 = require("../helpers/data");
const object_1 = require("../helpers/object");
const react_2 = require("../helpers/react");
const [useCtx, Provider] = (0, react_2.createCtx)();
exports.useDatatableWrapper = useCtx;
function DatatableWrapper({ headers, body, filterProps, sortProps, paginationProps, paginationOptionsProps, children }) {
    const [state, setState] = (0, react_1.useState)(getDefaultDatatableState({
        filterProps,
        headers,
        sortProps,
        paginationProps,
        paginationOptionsProps
    }));
    const tableHeadersRecordRef = (0, react_1.useRef)((0, object_1.convertArrayToRecord)(headers, 'prop'));
    // Store this in a ref because we might need it in case `headers` change.
    // Though, we don't want to put these into `useEffect` because they most likely
    // change over time.
    const controlPropsRef = (0, react_1.useRef)({
        filterProps,
        sortProps,
        paginationProps,
        paginationOptionsProps
    });
    (0, react_1.useEffect)(() => {
        // Resets the table if the headers passed down is different.
        if (headers !== undefined) {
            // Re-set the ref.
            tableHeadersRecordRef.current = (0, object_1.convertArrayToRecord)(headers, 'prop');
            // Re-set the initial state.
            setState(getDefaultDatatableState({
                filterProps: controlPropsRef.current.filterProps,
                headers,
                sortProps: controlPropsRef.current.sortProps,
                paginationProps: controlPropsRef.current.paginationProps,
                paginationOptionsProps: controlPropsRef.current.paginationOptionsProps
            }));
        }
    }, [headers]);
    (0, react_1.useEffect)(() => {
        // Resets the table if the data passed down is different.
        if (body !== undefined) {
            setState((oldState) => (Object.assign(Object.assign({}, oldState), { filter: '', pagination: Object.assign(Object.assign({}, oldState.pagination), { currentPage: 1 }) })));
        }
    }, [body]);
    const onFilterChange = (0, react_1.useCallback)((text) => {
        setState((oldState) => (Object.assign(Object.assign({}, oldState), { filter: text, pagination: Object.assign(Object.assign({}, oldState.pagination), { currentPage: 1 }) })));
    }, []);
    const onPaginationChange = (0, react_1.useCallback)((nextPage) => {
        setState((oldState) => (Object.assign(Object.assign({}, oldState), { pagination: Object.assign(Object.assign({}, oldState.pagination), { currentPage: nextPage }) })));
    }, []);
    const onRowsPerPageChange = (0, react_1.useCallback)((numOfPage) => {
        setState((oldState) => (Object.assign(Object.assign({}, oldState), { pagination: Object.assign(Object.assign({}, oldState.pagination), { rowsPerPage: numOfPage, currentPage: 1 }) })));
    }, []);
    const onSortChange = (0, react_1.useCallback)((nextSort) => {
        setState((oldState) => (Object.assign(Object.assign({}, oldState), { sort: nextSort })));
    }, []);
    const { filter, sort, pagination } = state;
    let data = body;
    let filteredDataLength = data.length;
    let maxPage = 1;
    if (state.isFilterable) {
        data = (0, data_1.filterData)(body, tableHeadersRecordRef.current, filter, filterProps === null || filterProps === void 0 ? void 0 : filterProps.filterValueObj);
        filteredDataLength = data.length;
    }
    data = (0, data_1.sortData)(data, sort, sortProps === null || sortProps === void 0 ? void 0 : sortProps.sortValueObj);
    if (pagination.rowsPerPage !== -1) {
        // Pagination needs.
        maxPage = Math.ceil(data.length / pagination.rowsPerPage);
        data = (0, data_1.paginateData)(data, pagination.currentPage, pagination.rowsPerPage);
    }
    return (react_1.default.createElement(Provider, { value: {
            headers,
            // Filter.
            isFilterable: state.isFilterable,
            filterState: state.filter,
            onFilterChange,
            // Sort.
            sortState: state.sort,
            onSortChange,
            // Pagination.
            currentPageState: state.pagination.currentPage,
            onPaginationChange,
            // Pagination options.
            rowsPerPageState: state.pagination.rowsPerPage,
            rowsPerPageOptions: state.pagination.rowsPerPageOptions,
            onRowsPerPageChange,
            // Data.
            maxPage,
            filteredDataLength,
            data
        } }, children));
}
exports.DatatableWrapper = DatatableWrapper;
// Helper functions.
function getDefaultDatatableState({ filterProps, paginationOptionsProps, paginationProps, sortProps, headers }) {
    var _a, _b, _c, _d, _e;
    const defaultSort = { order: 'asc', prop: '' };
    let isFilterable = filterProps !== undefined;
    for (const header of headers) {
        // Set the default sort header.
        if (
        // If the sorted prop is still "empty", then we assign it with the current header.
        (defaultSort.prop === '' && header.isSortable) ||
            // Or, if the header prop matches the initial state, then set it as well.
            header.prop === ((_a = sortProps === null || sortProps === void 0 ? void 0 : sortProps.initialState) === null || _a === void 0 ? void 0 : _a.prop)) {
            defaultSort.prop = header.prop.toString();
        }
        if (header.isFilterable) {
            isFilterable = true;
        }
    }
    // Define initial state.
    return {
        isFilterable,
        filter: ((_b = filterProps === null || filterProps === void 0 ? void 0 : filterProps.initialState) === null || _b === void 0 ? void 0 : _b.filter) || '',
        sort: defaultSort,
        pagination: {
            currentPage: ((_c = paginationProps === null || paginationProps === void 0 ? void 0 : paginationProps.initialState) === null || _c === void 0 ? void 0 : _c.page) || 1,
            rowsPerPage: ((_d = paginationOptionsProps === null || paginationOptionsProps === void 0 ? void 0 : paginationOptionsProps.initialState) === null || _d === void 0 ? void 0 : _d.rowsPerPage) || -1,
            rowsPerPageOptions: ((_e = paginationOptionsProps === null || paginationOptionsProps === void 0 ? void 0 : paginationOptionsProps.initialState) === null || _e === void 0 ? void 0 : _e.options) || []
        }
    };
}
