"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableBody = void 0;
const react_1 = __importDefault(require("react"));
const object_1 = require("../helpers/object");
const DatatableWrapper_1 = require("./DatatableWrapper");
function TableBody({ labels, classes, onRowClick }) {
    const { data, headers } = (0, DatatableWrapper_1.useDatatableWrapper)();
    const body = [];
    const dataLength = data.length;
    if (dataLength > 0) {
        for (let i = 0; i < dataLength; i += 1) {
            body.push(react_1.default.createElement(BodyRow, { key: `row-${i}`, classes: classes, headers: headers, data: data, onClick: onRowClick, rowIdx: i }));
        }
    }
    else {
        body.push(react_1.default.createElement("tr", { key: `row-zero-length`, className: "tbody-tr" },
            react_1.default.createElement("td", { className: "tbody-td", colSpan: headers.length }, (labels === null || labels === void 0 ? void 0 : labels.noResults) || 'No results to be shown.')));
    }
    return react_1.default.createElement("tbody", { className: (0, object_1.makeClasses)('tbody', classes === null || classes === void 0 ? void 0 : classes.tbody) }, body);
}
exports.TableBody = TableBody;
function BodyRow({ headers, data, rowIdx, classes, onClick }) {
    const row = [];
    for (let i = 0; i < headers.length; i += 1) {
        const { cell, cellProps = {} } = headers[i];
        let value = '';
        if (cell === undefined) {
            value = data[rowIdx][headers[i].prop];
        }
        else {
            value = cell(data[rowIdx]);
        }
        row.push(react_1.default.createElement("td", { key: `col-${rowIdx}${i}`, className: (0, object_1.makeClasses)('tbody-td', classes === null || classes === void 0 ? void 0 : classes.td, typeof cellProps.className === 'function'
                ? cellProps.className(data[rowIdx])
                : cellProps.className), style: typeof cellProps.style === 'function'
                ? cellProps.style(data[rowIdx])
                : cellProps.style }, value));
    }
    function onRowClick() {
        if (typeof onClick === 'function') {
            onClick(data[rowIdx]);
        }
    }
    return (react_1.default.createElement("tr", { className: (0, object_1.makeClasses)('tbody-tr', classes === null || classes === void 0 ? void 0 : classes.tr), onClick: onRowClick }, row));
}
