"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableHeader = void 0;
const react_1 = __importDefault(require("react"));
const DatatableWrapper_1 = require("./DatatableWrapper");
const FontAwesome_1 = __importDefault(require("./FontAwesome"));
const object_1 = require("../helpers/object");
function TableHeader({ tableHeaders, classes, controlledProps }) {
    const headings = [];
    const { onSortChange: onSortChangeContext, sortState: sortStateContext } = (0, DatatableWrapper_1.useDatatableWrapper)();
    const onSortChange = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.onSortChange) || onSortChangeContext;
    const sortState = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.sortState) || sortStateContext;
    for (let i = 0; i < tableHeaders.length; i += 1) {
        const { isSortable, prop, title, headerCell } = tableHeaders[i];
        const thClass = (0, object_1.makeClasses)({
            'thead-th': true,
            sortable: isSortable === true
        });
        const nextSort = { order: 'asc', prop: prop.toString() };
        const isCurrentSort = sortState.prop === prop;
        let sortIcon = 'sort';
        let sortIconRender = null;
        if (isSortable) {
            if (sortState.prop && isCurrentSort) {
                if (sortState.order === 'asc') {
                    sortIcon = 'sortUp';
                    nextSort.order = 'desc';
                }
                else {
                    sortIcon = 'sortDown';
                }
            }
            sortIconRender = react_1.default.createElement(FontAwesome_1.default, { icon: sortIcon, className: "fa-fw" });
        }
        let rendered;
        if (headerCell) {
            rendered = headerCell(sortIconRender, sortState);
        }
        else {
            rendered = (react_1.default.createElement(react_1.default.Fragment, null,
                title,
                react_1.default.createElement("span", null, sortIconRender)));
        }
        const thProps = {
            key: `th-${i}`,
            className: (0, object_1.makeClasses)(thClass, classes === null || classes === void 0 ? void 0 : classes.th)
        };
        if (isSortable) {
            thProps.onClick = () => onSortChange(nextSort);
            thProps.role = 'button';
            if (isCurrentSort) {
                thProps['data-sort-order'] = sortState.order;
            }
        }
        headings.push(react_1.default.createElement("th", Object.assign({}, thProps), rendered));
    }
    return (react_1.default.createElement("thead", { className: (0, object_1.makeClasses)('thead', classes === null || classes === void 0 ? void 0 : classes.thead) },
        react_1.default.createElement("tr", { className: (0, object_1.makeClasses)('thead-tr', classes === null || classes === void 0 ? void 0 : classes.tr) }, headings)));
}
exports.TableHeader = TableHeader;
