import React from 'react';
import { makeClasses } from '../helpers/object';
import { useDatatableWrapper } from './DatatableWrapper';
export function TableBody({ labels, classes, onRowClick }) {
    const { data, headers } = useDatatableWrapper();
    const body = [];
    const dataLength = data.length;
    if (dataLength > 0) {
        for (let i = 0; i < dataLength; i += 1) {
            body.push(React.createElement(BodyRow, { key: `row-${i}`, classes: classes, headers: headers, data: data, onClick: onRowClick, rowIdx: i }));
        }
    }
    else {
        body.push(React.createElement("tr", { key: `row-zero-length`, className: "tbody-tr" },
            React.createElement("td", { className: "tbody-td", colSpan: headers.length }, (labels === null || labels === void 0 ? void 0 : labels.noResults) || 'No results to be shown.')));
    }
    return React.createElement("tbody", { className: makeClasses('tbody', classes === null || classes === void 0 ? void 0 : classes.tbody) }, body);
}
function BodyRow({ headers, data, rowIdx, classes, onClick }) {
    const row = [];
    for (let i = 0; i < headers.length; i += 1) {
        const { cell, cellProps = {} } = headers[i];
        let value = '';
        if (cell === undefined) {
            value = data[rowIdx][headers[i].prop];
        }
        else {
            value = cell(data[rowIdx]);
        }
        row.push(React.createElement("td", { key: `col-${rowIdx}${i}`, className: makeClasses('tbody-td', classes === null || classes === void 0 ? void 0 : classes.td, typeof cellProps.className === 'function'
                ? cellProps.className(data[rowIdx])
                : cellProps.className), style: typeof cellProps.style === 'function'
                ? cellProps.style(data[rowIdx])
                : cellProps.style }, value));
    }
    function onRowClick() {
        if (typeof onClick === 'function') {
            onClick(data[rowIdx]);
        }
    }
    return (React.createElement("tr", { className: makeClasses('tbody-tr', classes === null || classes === void 0 ? void 0 : classes.tr), onClick: onRowClick }, row));
}
